@@ -55,7 +55,7 @@ def _env():
         autoescape = True,
         cache_size = cfg.TEMPLATE_CACHE_SIZE,
         auto_reload = cfg.TEMPLATE_AUTO_RELOAD,
-        extensions = ['jinja2.ext.with_'],
+        extensions = cfg.JINJA2_EXTENSIONS,
     )
 
 class FileLoader(object):
