@@ -290,13 +290,17 @@ class App(object):
         '''
         def routing_queue(routing):
             list_obj_from_str(routing)
+            if len(routing) == 1:
+                return routing[0]
             def wrapper(rq):
                 for func in routing:
                     try:
                         return func(rq)
-                    except NotFound:
-                        continue
-                raise NotFound
+                    except HttpError, e:
+                        if e[0] == 404:
+                            continue
+                        raise
+                abort(404)
             return wrapper
         
         try:
@@ -320,10 +324,7 @@ class App(object):
         self.response_middlewares = [m().process_response for m in mdls
             if hasattr(m, 'process_response')]
         self.response_middlewares.reverse()
-
-        self.routing = obj_from_str(cfg.ROUTING)
-        if isinstance(self.routing, (tuple, list)):
-            self.routing = routing_queue(self.routing)
+        self.routing = routing_queue(cfg.ROUTING_QUEUE)
 
     def __call__(self, environ, start_response):
         try:
@@ -344,7 +345,7 @@ class App(object):
         except HttpError, e:
             if cfg.DEBUG:
                 res = Response(make_traceback(rq.host),
-                    code=404, content_type='text/plain')
+                    code=e[0], content_type='text/plain')
             else:
                 res = get_error_page(rq, e[0])
         except Exception:
